==> dif-database-repository-2.7.1-sources.jar: pt/digitalis/dif/dem/managers/impl/model/data/DataConsentTransFieldAttributes.java <==
package pt.digitalis.dif.dem.managers.impl.model.data;

import pt.digitalis.utils.common.AttributeDefinition;
import pt.digitalis.dif.model.utils.AbstractBeanAttributesDefinition;

import java.sql.Timestamp;
import java.sql.Blob;
import java.util.Date;
import java.math.BigDecimal;

import java.util.Arrays;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import pt.digitalis.utils.common.collections.CaseInsensitiveHashMap;

import org.hibernate.Session;


/**
 *  Field definitions for data object {@link DataConsentTrans}
 *
 * NOTE: This file is auto generated and will be overwritten in a future file generation.
 */
public class DataConsentTransFieldAttributes extends AbstractBeanAttributesDefinition{

    /** dataConsent (Database column: CONSENT_ID - The consent) */
    static public AttributeDefinition dataConsent =
        new AttributeDefinition("dataConsent")
                .setDescription("The consent")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("DATA_CONSENT_TRANS")
                .setDatabaseId("CONSENT_ID")
                .setMandatory(true)
                .setMaxSize(255)
                .setLovDataClass(pt.digitalis.dif.dem.managers.impl.model.data.DataConsent.class)
                .setLovDataClassKey("id")
                .setLovDataClassDescription("description")
                .setType(pt.digitalis.dif.dem.managers.impl.model.data.DataConsent.class);

    /** description (Database column: DESCRIPTION - The description description) */
    static public AttributeDefinition description =
        new AttributeDefinition("description")
                .setDescription("The description description")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("DATA_CONSENT_TRANS")
                .setDatabaseId("DESCRIPTION")
                .setMandatory(true)
                .setMaxSize(255)
                .setType(String.class);

    /** id (Database column: ID - ID) */
    static public AttributeDefinition id =
        new AttributeDefinition("id")
                .setDescription("ID")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("DATA_CONSENT_TRANS")
                .setDatabaseId("ID")
                .setMandatory(true)
                .setMaxSize(255)
                .setType(Long.class);

    /** languageId (Database column: LANGUAGE_ID - The language ID) */
    static public AttributeDefinition languageId =
        new AttributeDefinition("languageId")
                .setDescription("The language ID")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("DATA_CONSENT_TRANS")
                .setDatabaseId("LANGUAGE_ID")
                .setMandatory(true)
                .setMaxSize(10)
                .setType(String.class);

    /** title (Database column: TITLE - The title translation) */
    static public AttributeDefinition title =
        new AttributeDefinition("title")
                .setDescription("The title translation")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("DATA_CONSENT_TRANS")
                .setDatabaseId("TITLE")
                .setMandatory(true)
                .setMaxSize(1000)
                .setType(String.class);

    /**
    * Create definitions map map.
    *
    * @return the map
    */
    @Override protected CaseInsensitiveHashMap<AttributeDefinition> createDefinitionsMap(){
        CaseInsensitiveHashMap<AttributeDefinition> map = new CaseInsensitiveHashMap<AttributeDefinition>();
        map.put(dataConsent.getName(),dataConsent);
        map.put(description.getName(),description);
        map.put(id.getName(),id);
        map.put(languageId.getName(),languageId);
        map.put(title.getName(),title);

        return map;
    }
}

==> dif-database-repository-2.7.3-5-sources.jar: pt/digitalis/dif/dem/managers/impl/model/data/DataConsentTransFieldAttributes.java <==
package pt.digitalis.dif.dem.managers.impl.model.data;

import pt.digitalis.utils.common.AttributeDefinition;
import pt.digitalis.dif.model.utils.AbstractBeanAttributesDefinition;

import java.sql.Timestamp;
import java.sql.Blob;
import java.util.Date;
import java.math.BigDecimal;

import java.util.Arrays;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import pt.digitalis.utils.common.collections.CaseInsensitiveHashMap;

import org.hibernate.Session;


/**
 *  Field definitions for data object {@link DataConsentTrans}
 *
 * NOTE: This file is auto generated and will be overwritten in a future file generation.
 */
public class DataConsentTransFieldAttributes extends AbstractBeanAttributesDefinition{

    /** dataConsent (Database column: CONSENT_ID - The consent) */
    static public AttributeDefinition dataConsent =
        new AttributeDefinition("dataConsent")
                .setDescription("The consent")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("DATA_CONSENT_TRANS")
                .setDatabaseId("CONSENT_ID")
                .setMandatory(true)
                .setMaxSize(10)
                .setLovDataClass(pt.digitalis.dif.dem.managers.impl.model.data.DataConsent.class)
                .setLovDataClassKey("id")
                .setLovDataClassDescription("description")
                .setType(pt.digitalis.dif.dem.managers.impl.model.data.DataConsent.class);

    /** description (Database column: DESCRIPTION - The description description) */
    static public AttributeDefinition description =
        new AttributeDefinition("description")
                .setDescription("The description description")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("DATA_CONSENT_TRANS")
                .setDatabaseId("DESCRIPTION")
                .setMandatory(false)
                .setMaxSize(4000)
                .setType(String.class);

    /** id (Database column: ID - ID) */
    static public AttributeDefinition id =
        new AttributeDefinition("id")
                .setDescription("ID")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("DATA_CONSENT_TRANS")
                .setDatabaseId("ID")
                .setMandatory(true)
                .setMaxSize(10)
                .setType(Long.class);

    /** languageId (Database column: LANGUAGE_ID - The language ID) */
    static public AttributeDefinition languageId =
        new AttributeDefinition("languageId")
                .setDescription("The language ID")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("DATA_CONSENT_TRANS")
                .setDatabaseId("LANGUAGE_ID")
                .setMandatory(true)
                .setMaxSize(10)
                .setType(String.class);

    /** title (Database column: TITLE - The title translation) */
    static public AttributeDefinition title =
        new AttributeDefinition("title")
                .setDescription("The title translation")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("DATA_CONSENT_TRANS")
                .setDatabaseId("TITLE")
                .setMandatory(true)
                .setMaxSize(1000)
                .setType(String.class);

    /**
     * Gets description field.
     *
     * @return the description field
     */
    public static String getDescriptionField()
    {
        return null;
    }

    /**
    * Create definitions map map.
    *
    * @return the map
    */
    @Override protected CaseInsensitiveHashMap<AttributeDefinition> createDefinitionsMap(){
        CaseInsensitiveHashMap<AttributeDefinition> map = new CaseInsensitiveHashMap<AttributeDefinition>();
        map.put(dataConsent.getName(),dataConsent);
        map.put(description.getName(),description);
        map.put(id.getName(),id);
        map.put(languageId.getName(),languageId);
        map.put(title.getName(),title);

        return map;
    }
}
